library(ggplot2)
library(plyr)
library(tidyr)
library(dplyr)
library(gridExtra)  


plot.R0 <- function(packagepath, parametre){
  trace <- as.data.frame(read.csv(paste(packagepath,"/pmcmc-result/trace_0.csv",sep=""), header = TRUE))
  ncol_param=which(names(trace)==as.character(parametre))
  ncol_index=which(names(trace)=="index")
  
  trace=trace[,c(ncol_index, ncol_param)]
  trace$sqrt_R0=sqrt(trace$R0)
  print(quantile(trace$sqrt_R0, c(0.025,0.5, 0.975)))
  
  colour <- c(posterior = "#7570b3")
  
  p <- ggplot(trace, aes(x = sqrt_R0)) 
  p <- p + geom_histogram(data = trace, aes(y = ..density..), 
                          fill = colour[["posterior"]], colour = colour[["posterior"]], 
                          alpha = 0.5)
  p <- p + ylab("") + xlab("R0") + xlim(1.5, 4.5) +   theme(panel.background = element_rect(fill = 'white'), panel.grid.major = element_line(colour = "lightgrey", linetype = "dashed"))
  p <- p + theme(axis.text.x = element_text(size=45))  + theme(axis.text.y = element_text(size=45))+  theme(axis.title.x = element_text(size=50,margin=margin(20,0,0,0)))
  p <- p + scale_x_continuous(breaks = c(1.5, 2,2.5, 3,3.5,4,4.5),limits=c(1.3, 4.5))
  p <- p+ theme(axis.line.x = element_line(color="black"), axis.line.y = element_line(color="black"))
  return(p)
  
}

plotStateFit <- function(Xpath,packagepath,state, end_date, start_date,  model, ordonnee, ylim){
  X <- as.data.frame(read.csv(paste(packagepath,Xpath,sep=""), header = TRUE))
  data <- as.data.frame(read.csv(paste(packagepath,"/data/data.csv",sep=""), header = TRUE))
  
  X <- X %>% mutate(date=as.Date(date)) %>% gather(state, value, -date, -index) %>% group_by(date, state) %>% summarize(mean=mean(value), median=median(value), lower_50=quantile(value, 0.25), upper_50=quantile(value, 0.75), lower_95=quantile(value, 0.025), upper_95=quantile(value, 0.975))
  X= X[X$state==state,]
  datanames = names(data)
  data$date=as.Date(data$date)
  X <- merge(X,data, all=TRUE)
  X$mod=model
  Sys.setlocale("LC_TIME", "en_US.UTF-8")
  ggplot(X[X$date>=start_date & X$date<=end_date,],aes_string(x='date',y ="median")) + facet_wrap(~mod, scales="fixed")+
    geom_ribbon(aes_string(ymin= "lower_95", ymax="upper_95"),fill="skyblue",alpha=0.55) +
    #geom_ribbon(aes_string(ymin= "lower_50", ymax="upper_50"),fill="skyblue",alpha=1) +
    geom_line(color="dodgerblue4",size=0.7)+ theme(axis.line.x = element_line(color="black"), axis.line.y = element_line(color="black"))+
    geom_point(aes_string(x='date', y=paste("incidence_obs")),color="black", size=7)+
    theme(axis.text.x = element_text(size=45)) + theme(axis.text.y = element_text(size=45))+theme(strip.background = element_blank())+
    theme(axis.title = element_text(size=50)) +ylab("") + xlab("") + ylim(0,ylim) +
    theme(panel.background = element_rect(fill = 'white'), panel.grid.major = element_line(colour = "lightgrey", linetype = "dashed"))
}


plot_filtre <- function(packagepath,state, model, ordonnee, ylim){
  X <- as.data.frame(read.csv(paste(packagepath,"/pmcmc-result/X_0.csv",sep=""), header = TRUE))
  data <- as.data.frame(read.csv(paste(packagepath,"/data/data.csv",sep=""), header = TRUE))
  
  X <- X %>% mutate(date=as.Date(date)) %>% gather(state, value, -date, -index) %>% group_by(date, state) %>% summarize(mean=mean(value), median=median(value), lower_50=quantile(value, 0.25), upper_50=quantile(value, 0.75), lower_95=quantile(value, 0.025), upper_95=quantile(value, 0.975))
  X= X[X$state==state,]
  datanames = names(data)
  data$date=as.Date(data$date)
  X <- merge(X,data, all=TRUE)
  X$mod=model
  Sys.setlocale("LC_TIME", "en_US.UTF-8")
  ggplot(X,aes_string(x='date',y ="median")) + facet_wrap(~mod, scales="fixed")+
    geom_ribbon(aes_string(ymin= "lower_95", ymax="upper_95"),fill="skyblue",alpha=0.55) +
    #geom_ribbon(aes_string(ymin= "lower_50", ymax="upper_50"),fill="skyblue",alpha=1) +
    geom_line(color="dodgerblue4",size=0.7)+ theme(axis.line.x = element_line(color="black"), axis.line.y = element_line(color="black"))+
    geom_point(aes_string(x='date', y=paste("incidence_obs")),color="black", size=7)+
    theme(axis.text.x = element_text(size=45)) + theme(axis.text.y = element_text(size=45))+theme(strip.background = element_blank())+
    theme(axis.title = element_text(size=50)) +ylab("") + xlab("") + ylim(0,ylim) +
    theme(panel.background = element_rect(fill = 'white'), panel.grid.major = element_line(colour = "lightgrey", linetype = "dashed"))
}


###########
# Tahiti Pandey model
###########
Tahiti1 <- plot_filtre(packagepath="Tahiti_Pandey", state= "incidence_obs", model = "",  ordonnee="observed incidence", ylim=900 )
Tahiti2 <- plotStateFit(Xpath="/pmcmc-result/X_simul.csv",packagepath = "Tahiti_Pandey", state= "incidence_obs",start_date = "2013-10-07",end_date = "2014-03-28", model = "",  ordonnee="observed incidence", ylim=900  )
Tahiti3 <- plot.R0(packagepath="Tahiti_Pandey", parametre="R0")


Tahiti1b=Tahiti1+ theme(plot.margin=unit(c(1,1,0.5,0.5), "cm"))
Tahiti2b=Tahiti2+ theme(plot.margin=unit(c(1,1,0.5,0.5), "cm"))
Tahiti3b=Tahiti3+ theme(plot.margin=unit(c(1,0,0.5,0.5), "cm"))

tahiti = arrangeGrob(Tahiti1b, Tahiti2b, Tahiti3b, ncol=3, widths=c(20,20, 20), padding = unit(10, "line"))
ggsave(file.path("Graphes","main_tahiti_pandey.pdf"),tahiti, width=40, height=10)




